from os import environ


class SkillsNetworkEdxMiddleware(object):
    """
    Middleware to report errors to Skills Network staff
    """

    def __init__(self, get_response=None):
        self.get_response = get_response

    def __call__(self, request):  # pragma: no cover
        self.process_request(request)
        try:
            response = self.get_response(request)
        except Exception as e:
            self.process_exception(request, e)
            raise
        return self.process_response(request, response)

    def process_request(self, request):
        print("processing request")

    def process_response(self, request, response):
        print(environ)
        print(environ.get("RELEASE_NAME"))
        print("processing response")
        return response

    def process_exception(self, request, exception):
        print("processing exception")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sn-edx-middleware",
    version="0.0.1",
    author="James Reeve",
    author_email="james.reeve@ibm.com",
    description="middleware for Skills Network deployments of openedx",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.ibm.com/skills-network-portals/sn-edx-middleware",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
